clear
% 
% Read in the relevant data from txt files
YCHARS = importdata('/CHL/Data/yearlychars.txt'); 
% Yearly characteristics
 
MOM = importdata('/CHL/Data/rawmom.txt'); 
% Monthly Momentum characteristics

OWNVAR = importdata('/CHL/Data/rawownvar.txt'); 
% Monthly Volatility characteristics

RRAW = importdata('/CHL/Data/rets.txt'); 
% Monthly returns

NFirms = importdata('/CHL/Data/yearnums.txt'); 
% Number of firms

FirmDate = NFirms(:,1);
NFirms(:,1)=[];
CumNFirm = cumsum(NFirms);


% Reorganize monthly
 data
Nmax = max(NFirms); 
% maximum number of firms

T = 12*length(NFirms); 
% number of periods


% Allocate space


R = NaN(T,Nmax);

C.BP = NaN(T,Nmax);

C.MOM = NaN(T,Nmax);

C.VOL = NaN(T,Nmax);

C.SIZE = NaN(T,Nmax);

I = NaN(T,Nmax);

TInd = NaN(T,1); 
% time index


% Enter colums in which is yearly data

BP_Ind = 6;

Size_Ind = 5;

Ind_Ind = 3;


for i = 1:length(NFirms)

    indexD = (CumNFirm(i) - NFirms(i) + 1):CumNFirm(i);

    for j=1:12
        indexM = i*12-12+j;

        % Grab the right data for yearly reported data

        tempdataBP = YCHARS(indexD,BP_Ind);

        tempdataSize = YCHARS(indexD,Size_Ind);

        tempdataInd = YCHARS(indexD,Ind_Ind);

        % Grab the right data for monthly reported data

        tempdataMOM = MOM(indexD,j);

        tempdataVOL = OWNVAR(indexD,j);

        tempdataRets = RRAW(indexD,j);

        % Fill in data yearly (repeat rows)

        C.BP(indexM,1:length(indexD)) = tempdataBP';

        C.SIZE(indexM,1:length(indexD)) = tempdataSize';

        I(indexM,1:length(indexD)) = tempdataInd';

        % Fill in data monthly

        C.MOM(indexM,1:length(indexD)) = tempdataMOM';

        C.VOL(indexM,1:length(indexD)) = tempdataVOL';

        R(indexM,1:length(indexD)) = tempdataRets';

        % Generate date vector

        TInd(indexM) = FirmDate(i)*100 + j;
 
    end

end


% Modify beginning and end of the TInd vector to allow for July-June definition of year
Ind = [TInd; 200701; 200702; 200703; 200704; 200705; 200706];

TInd(1:6)=[];

% Find standard deviation as square root of variance.
VOL = C.VOL.^0.5;



% Use Z-score function to standardize the characteristics

Cz.BP = zscore(C.BP);

Cz.SIZE = zscore(C.SIZE);

Cz.MOM = zscore(C.MOM);

Cz.VOL = zscore(C.VOL);


% save the data

save('/CHL/Data/MLData.mat','C','Cz','R','I','TInd')